@@ -85,9 +85,14 @@ typedef struct {
 	char *indicator_pixbuf_name;
 	GdkPixbuf *indicator_pixbuf;
 	int notebook_page;
-	Bonobo_Listener listener;
 	GtkWidget *tab_view;
 	GdkRectangle tab_rect;
+
+	NautilusSidebarTabs *parent;
+
+	BonoboListener      *listener;
+	Bonobo_PropertyBag   property_bag;
+	Bonobo_EventSource   event_source;
 } TabItem;
 
 struct NautilusSidebarTabsDetails {
@@ -104,7 +109,6 @@ struct NautilusSidebarTabsDetails {
 	GdkColor prelit_text_color;
 
 	GdkPixbuf *tab_piece_images[LAST_TAB_OFFSET];
-	PangoFontDescription *tab_font;
 	int tab_height;
 	int tab_left_offset;
 	char *title;
@@ -124,8 +128,8 @@ struct NautilusSidebarTabsDetails {
 
 /* headers */
 
-static void     nautilus_sidebar_tabs_class_init  (NautilusSidebarTabsClass *klass);
-static void     nautilus_sidebar_tabs_init        (NautilusSidebarTabs      *pixmap);
+static void     nautilus_sidebar_tabs_class_init        (NautilusSidebarTabsClass *klass);
+static void     nautilus_sidebar_tabs_init              (NautilusSidebarTabs      *pixmap);
 static int      nautilus_sidebar_tabs_expose            (GtkWidget                *widget,
 							 GdkEventExpose           *event);
 static void     nautilus_sidebar_tabs_destroy           (GtkObject                *object);
@@ -138,7 +142,13 @@ static void     draw_or_layout_all_tabs                 (NautilusSidebarTabs
 							 gboolean                  layout_only);
 static TabItem* tab_item_find_by_name                   (NautilusSidebarTabs      *sidebar_tabs,
 							 const char               *name);
-static void     default_font_changed_callback           (gpointer                  callback_data);
+static void     style_set                               (GtkWidget                *widget,
+							 GtkStyle                 *previous_style);
+static void     tab_indicator_changed_callback          (BonoboListener           *listener,
+							 const char               *event_name,
+							 const CORBA_any          *arg,
+							 CORBA_Environment        *ev,
+							 gpointer                  callback_data);
 
 EEL_CLASS_BOILERPLATE (NautilusSidebarTabs, nautilus_sidebar_tabs, GTK_TYPE_WIDGET)
 
@@ -154,6 +164,7 @@ nautilus_sidebar_tabs_class_init (NautilusSidebarTabsClass *class)
 	object_class->destroy = nautilus_sidebar_tabs_destroy;
 	widget_class->expose_event = nautilus_sidebar_tabs_expose;
 	widget_class->size_allocate = nautilus_sidebar_tabs_size_allocate;
+	widget_class->style_set = style_set;
 }
 
 /* utilities to set up the text color alternatives */
@@ -235,35 +246,19 @@ nautilus_sidebar_tabs_load_theme_data (NautilusSidebarTabs *sidebar_tabs)
 				}
 			}
 		}	
-	}	
-
-	default_font_changed_callback (sidebar_tabs);
+	}
+	
+	gtk_widget_queue_resize (GTK_WIDGET (sidebar_tabs));
 }
 
-/* Use the font from preferences */
+static void recalculate_size(NautilusSidebarTabs *sidebar_tabs);
+
 static void
-default_font_changed_callback (gpointer callback_data)
+style_set (GtkWidget *widget,
+	   GtkStyle  *previous_style)
 {
-	PangoFontDescription *new_font;
-	char *font_name;
-	NautilusSidebarTabs *sidebar_tabs;
-
-	g_return_if_fail (NAUTILUS_IS_SIDEBAR_TABS (callback_data));
-
-	sidebar_tabs = NAUTILUS_SIDEBAR_TABS (callback_data);
-
-	font_name = eel_preferences_get (NAUTILUS_PREFERENCES_DEFAULT_FONT);
-	new_font = pango_font_description_from_string (font_name);
-	pango_font_description_set_size (new_font, DEFAULT_FONT_SIZE * PANGO_SCALE);
-	
-	if (sidebar_tabs->details->tab_font != NULL) {
-		pango_font_description_free (sidebar_tabs->details->tab_font);
-		sidebar_tabs->details->tab_font = NULL;
-	}
-
-	sidebar_tabs->details->tab_font = new_font;
-
-	gtk_widget_queue_resize (GTK_WIDGET (sidebar_tabs));
+	recalculate_size (NAUTILUS_SIDEBAR_TABS (widget));
+	gtk_widget_queue_resize (widget);
 }
 
 /* initialize a newly allocated sidebar tabs object */
@@ -303,10 +298,6 @@ nautilus_sidebar_tabs_init (NautilusSidebarTabs *sidebar_tabs)
 				     (EelPreferencesCallback) nautilus_sidebar_tabs_load_theme_data, 
 				     sidebar_tabs);
 
-	eel_preferences_add_callback (NAUTILUS_PREFERENCES_DEFAULT_FONT,
-				      default_font_changed_callback,
-				      sidebar_tabs);
-	
 	sidebar_tabs->details->title_prelit = FALSE;
 }
 
@@ -321,27 +312,34 @@ get_property_bag (TabItem *item)
 {
 	Bonobo_Control control;
 	CORBA_Environment ev;
-	Bonobo_PropertyBag property_bag;
 
-	control = nautilus_view_frame_get_control (NAUTILUS_VIEW_FRAME (item->tab_view));	
-	if (control == NULL) {
-		return CORBA_OBJECT_NIL;
+	if (item->property_bag == CORBA_OBJECT_NIL) {
+		if (item->tab_view == NULL) {
+			return CORBA_OBJECT_NIL;
+		}
+
+		control = nautilus_view_frame_get_control
+			(NAUTILUS_VIEW_FRAME (item->tab_view));	
+		if (control == NULL) {
+			return CORBA_OBJECT_NIL;
+		}
+
+		CORBA_exception_init (&ev);
+		item->property_bag = Bonobo_Control_getProperties (control, &ev);
+		if (BONOBO_EX (&ev)) {
+			item->property_bag = CORBA_OBJECT_NIL;
+		}
+		CORBA_exception_free (&ev);
 	}
 
-	CORBA_exception_init (&ev);
-	property_bag = Bonobo_Control_getProperties (control, &ev);
-	if (BONOBO_EX (&ev)) {
-		property_bag = CORBA_OBJECT_NIL;
-	}
-	CORBA_exception_free (&ev);
-	return property_bag;
+	return item->property_bag;
 }
 
 /* utility to destroy all the storage used by a tab item */
 static void
 tab_item_destroy (TabItem *item)
 {
-	Bonobo_PropertyBag property_bag;
+	BonoboListener *listener;
 	CORBA_Environment ev;
 
 	g_free (item->tab_text);
@@ -351,20 +349,38 @@ tab_item_destroy (TabItem *item)
 		g_object_unref (item->indicator_pixbuf);
 	}
 
-	if (item->listener != CORBA_OBJECT_NIL) {
-		CORBA_exception_init (&ev);
+	CORBA_exception_init (&ev);
 
-		property_bag = get_property_bag (item);
-		if (property_bag != CORBA_OBJECT_NIL) {
-			bonobo_event_source_client_remove_listener
-				(property_bag, item->listener, &ev);
-			bonobo_object_release_unref (property_bag, &ev);
-		}
-		CORBA_Object_release (item->listener, &ev);
-
-		CORBA_exception_free (&ev);
+	if ((listener = item->listener)) {
+		g_signal_handlers_disconnect_matched (
+			item->listener, G_SIGNAL_MATCH_FUNC,
+			0, 0, NULL, G_CALLBACK (tab_indicator_changed_callback), NULL);
+		item->listener = NULL;
 	}
 
+	if (listener != NULL &&
+	    item->event_source != CORBA_OBJECT_NIL) {
+		Bonobo_EventSource_removeListener
+			(item->event_source,
+			 BONOBO_OBJREF (listener),
+			 &ev);
+	}
+
+	if (item->event_source != CORBA_OBJECT_NIL) {
+		CORBA_Object_release (item->event_source, &ev);
+	}
+
+	if (item->property_bag != CORBA_OBJECT_NIL) {
+		CORBA_Object_release (item->property_bag, &ev);
+	}
+	CORBA_exception_free (&ev);
+
+	if (listener) {
+		bonobo_object_unref (BONOBO_OBJECT (listener));
+	}
+
+	eel_remove_weak_pointer (&item->tab_view);
+
 	g_free (item);
 }
 
@@ -401,12 +417,6 @@ nautilus_sidebar_tabs_destroy (GtkObject *object)
 						 (EelPreferencesCallback) nautilus_sidebar_tabs_load_theme_data, 
 						 sidebar_tabs);
 
-		eel_preferences_remove_callback (NAUTILUS_PREFERENCES_DEFAULT_FONT,
-						 default_font_changed_callback,
-						 sidebar_tabs);
-
-		pango_font_description_free (sidebar_tabs->details->tab_font);
-		
 		g_free (sidebar_tabs->details);
 		sidebar_tabs->details = NULL;
 	}
@@ -476,7 +486,8 @@ nautilus_sidebar_tabs_load_tab_pieces (NautilusSidebarTabs *sidebar_tabs, const
 /* determine the tab associated with the passed-in coordinates, and pass back the notebook
    page index associated with it.  */
 
-int nautilus_sidebar_tabs_hit_test (NautilusSidebarTabs *sidebar_tabs, int x, int y)
+int
+nautilus_sidebar_tabs_hit_test (NautilusSidebarTabs *sidebar_tabs, int x, int y)
 {
 	GList *current_item;
 	TabItem *tab_item;
@@ -593,9 +604,29 @@ pixbuf_composite (GdkPixbuf *source, GdkPixbuf *destination, int x_offset, int y
 			      float_x_offset, float_y_offset, 1.0, 1.0, GDK_PIXBUF_ALPHA_BILEVEL, alpha);
 }
 
+static PangoLayout *
+make_tab_text_layout (NautilusSidebarTabs *sidebar_tabs,
+		      const char *tab_name)
+{
+	PangoLayout *layout;
+	PangoFontDescription *desc;
+	PangoContext *context;
+
+	context = eel_gtk_widget_get_pango_ft2_context (GTK_WIDGET (sidebar_tabs));
+	layout = pango_layout_new (context);
+	pango_layout_set_text (layout, tab_name, -1);
+	
+	desc = pango_font_description_copy (pango_context_get_font_description (context));
+	pango_font_description_set_size (desc, DEFAULT_FONT_SIZE * PANGO_SCALE);
+	pango_layout_set_font_description (layout, desc);
+	pango_font_description_free (desc);
+
+	return layout;
+}
+
 /* draw a single tab using the default, non-themed approach */
 static int
-draw_one_tab_plain (NautilusSidebarTabs *sidebar_tabs, GdkGC *gc, char *tab_name,
+draw_one_tab_plain (NautilusSidebarTabs *sidebar_tabs, GdkGC *gc, const char *tab_name,
 		    GdkPixbuf *indicator_pixbuf, int x, int y, gboolean prelight_flag, GdkRectangle *tab_rect)
 {  
 	int tab_bottom;
@@ -616,10 +647,7 @@ draw_one_tab_plain (NautilusSidebarTabs *sidebar_tabs, GdkGC *gc, char *tab_name
 		indicator_width = 0;
 	}
 
-	layout = pango_layout_new (eel_gtk_widget_get_pango_ft2_context (GTK_WIDGET (sidebar_tabs)));
-	pango_layout_set_text (layout, tab_name, -1);
-	pango_layout_set_font_description (layout, sidebar_tabs->details->tab_font);
-	
+	layout = make_tab_text_layout (sidebar_tabs, tab_name);
 	pango_layout_get_pixel_size (layout, &text_width, &text_height);
 
 	total_width = text_width + indicator_width + 2 * TAB_MARGIN;
@@ -763,7 +791,7 @@ draw_tab_piece_aa (NautilusSidebarTabs *sidebar_tabs, GdkPixbuf *dest_pixbuf, in
    to do it properly at this time.  We draw into an offscreen pixbuf so we can get nice anti-aliased text */
 static int
 draw_one_tab_themed (NautilusSidebarTabs *sidebar_tabs, GdkPixbuf *tab_pixbuf, GdkPixbuf *indicator_pixbuf,
-		     char *tab_name, int x, int y, gboolean prelight_flag, 
+		     const char *tab_name, int x, int y, gboolean prelight_flag, 
 		     gboolean first_flag, gboolean prev_invisible, int text_h_offset,
 		     GdkRectangle *tab_rect)
 {  
@@ -795,10 +823,7 @@ draw_one_tab_themed (NautilusSidebarTabs *sidebar_tabs, GdkPixbuf *tab_pixbuf, G
 	}
 	
 	/* measure the size of the name */
-	layout = pango_layout_new (eel_gtk_widget_get_pango_ft2_context (GTK_WIDGET (sidebar_tabs)));
-	pango_layout_set_text (layout, tab_name, -1);
-	pango_layout_set_font_description (layout, sidebar_tabs->details->tab_font);
-	
+	layout = make_tab_text_layout (sidebar_tabs, tab_name);
 	pango_layout_get_pixel_size (layout, &text_width, NULL);
 
 	/* draw the left edge piece */
@@ -896,8 +921,7 @@ get_tab_width (NautilusSidebarTabs *sidebar_tabs, TabItem *this_tab, gboolean is
 	} else {	
 		edge_width = 2 * TAB_MARGIN;
 	}
-	layout = pango_layout_new (eel_gtk_widget_get_pango_ft2_context (GTK_WIDGET (sidebar_tabs)));
-	pango_layout_set_text (layout, this_tab->tab_text, -1);
+	layout = make_tab_text_layout (sidebar_tabs, this_tab->tab_text);
 	pango_layout_get_pixel_size (layout, &text_width, NULL);
 	g_object_unref (layout);
 
@@ -1325,17 +1349,27 @@ get_tab_image_name (TabItem *tab_item)
 
 	tab_image_name = bonobo_property_bag_client_get_value_string
 		(property_bag, "tab_image", NULL);
-	bonobo_object_release_unref (property_bag, NULL);
+
 	return tab_image_name;
 }
 
 /* update the indicator image for the passed in tab */
 static void
-nautilus_sidebar_tabs_update_tab_item (NautilusSidebarTabs *sidebar_tabs, TabItem *tab_item)
+nautilus_sidebar_tabs_update_tab_item (TabItem    *tab_item,
+				       const char *opt_new_image_name)
 {
+	NautilusSidebarTabs *sidebar_tabs;
 	char *tab_image_name, *image_path;
 	
-	tab_image_name = get_tab_image_name (tab_item);
+	g_return_if_fail (tab_item != NULL);
+	sidebar_tabs = tab_item->parent;
+	g_return_if_fail (NAUTILUS_IS_SIDEBAR_TABS (sidebar_tabs));
+
+	if (opt_new_image_name) {
+		tab_image_name = g_strdup (opt_new_image_name);
+	} else {
+		tab_image_name = get_tab_image_name (tab_item);
+	}
 
 	/* see if the indicator icon changed; if so, fetch the new one */
 	if (eel_strcmp (tab_image_name, tab_item->indicator_pixbuf_name) != 0) {
@@ -1377,82 +1411,100 @@ get_tab_item_from_view (NautilusSidebarTabs *sidebar_tabs, GtkWidget *view)
 	return NULL;
 }
 
-/* check all of the tabs to see if their indicator pixmaps are ready for updating */
 static void
-nautilus_sidebar_tabs_update_all_indicators (NautilusSidebarTabs *sidebar_tabs)
-{
-	GList *node;
-	TabItem *tab_item;
-
-	for (node = sidebar_tabs->details->tab_items; node != NULL; node = node->next) {
-		tab_item = node->data;
-		nautilus_sidebar_tabs_update_tab_item (sidebar_tabs, tab_item);				
-	}
-}
-
-/* check all of the tabs to see if their indicator pixmaps are ready for updating */
-static void
-nautilus_sidebar_tabs_update_indicator (NautilusSidebarTabs *sidebar_tabs, GtkWidget *view)
-{
-	GList *node;
-	TabItem *tab_item;
-	
-	for (node = sidebar_tabs->details->tab_items; node != NULL; node = node->next) {
-		tab_item = node->data;
-		if (tab_item->tab_view == view) {
-			nautilus_sidebar_tabs_update_tab_item (sidebar_tabs, tab_item);				
-			break;
-		}
-	}
-}
-
-static void
-tab_indicator_changed_callback (BonoboListener *listener,
-				const char *event_name,
-				const CORBA_any *arg,
+tab_indicator_changed_callback (BonoboListener    *listener,
+				const char        *event_name,
+				const CORBA_any   *arg,
 				CORBA_Environment *ev,
-				gpointer callback_data)
+				gpointer           callback_data)
 {
-	NautilusSidebarTabs *sidebar_tabs;
+	TabItem *tab_item;
 
-	sidebar_tabs = NAUTILUS_SIDEBAR_TABS (callback_data);
-	nautilus_sidebar_tabs_update_all_indicators (sidebar_tabs);	
+	tab_item = callback_data;
+
+	g_return_if_fail (bonobo_arg_type_is_equal
+			  (arg->_type, TC_CORBA_string, NULL));
+
+	nautilus_sidebar_tabs_update_tab_item
+		(tab_item, BONOBO_ARG_GET_STRING (arg));
 }
 
 /* listen for changes on the tab_image property */
 void
-nautilus_sidebar_tabs_connect_view (NautilusSidebarTabs *sidebar_tabs, GtkWidget *view)
+nautilus_sidebar_tabs_connect_view (NautilusSidebarTabs *sidebar_tabs,
+				    GtkWidget           *view)
 {
 	TabItem *tab_item;
+	CORBA_Environment ev;
 	Bonobo_PropertyBag property_bag;
+
+	g_return_if_fail (NAUTILUS_IS_SIDEBAR_TABS (sidebar_tabs));
+	g_return_if_fail (NAUTILUS_IS_VIEW_FRAME (view));
 	
 	tab_item = get_tab_item_from_view (sidebar_tabs, view);
 	if (tab_item == NULL) {
 		return;
 	}
-	
+
+	g_object_ref (G_OBJECT (sidebar_tabs));
+
 	property_bag = get_property_bag (tab_item);
 	if (property_bag != CORBA_OBJECT_NIL) {
-		tab_item->listener = bonobo_event_source_client_add_listener_full
-			(property_bag,
-			 g_cclosure_new (G_CALLBACK (tab_indicator_changed_callback), sidebar_tabs, NULL), 
-			 "Bonobo/Property:change:tab_image", NULL); 
-		bonobo_object_release_unref (property_bag, NULL);
+		CORBA_exception_init (&ev);
+
+		tab_item->listener = g_object_new (BONOBO_TYPE_LISTENER, NULL);
+		g_signal_connect (tab_item->listener, "event_notify",
+				  G_CALLBACK (tab_indicator_changed_callback),
+				  tab_item);
+
+		tab_item->event_source = Bonobo_Unknown_queryInterface
+			(property_bag, "IDL:Bonobo/EventSource:1.0", &ev);
+		if (BONOBO_EX (&ev)) {
+			tab_item->event_source = CORBA_OBJECT_NIL;
+		}
+
+		/* FIXME: it would be nice to be able to dispose
+		 * the BonoboListener explicitely
+		 */
+		if (tab_item->event_source != CORBA_OBJECT_NIL) {
+			Bonobo_EventSource_addListenerWithMask
+				(tab_item->event_source,
+				 BONOBO_OBJREF (tab_item->listener),
+				 "Bonobo/Property:change:tab_image",
+				 &ev); 
+
+			Bonobo_Unknown_unref (tab_item->event_source, &ev);
+		} else {
+			bonobo_object_unref (BONOBO_OBJECT (tab_item->listener));
+			tab_item->listener = NULL;
+		}
+
+		CORBA_exception_free (&ev);
 	}
 
-	nautilus_sidebar_tabs_update_indicator (sidebar_tabs, view);
+	/* might have strangely re-entered ? */
+	tab_item = get_tab_item_from_view (sidebar_tabs, view);
+	if (tab_item == NULL) {
+		return;
+	}
+
+	nautilus_sidebar_tabs_update_tab_item (tab_item, NULL);
+
+	g_object_unref (G_OBJECT (sidebar_tabs));
 }
 
 /* add a new tab entry, return TRUE if we succeed */
-
 gboolean
-nautilus_sidebar_tabs_add_view (NautilusSidebarTabs *sidebar_tabs, const char *name, GtkWidget *new_view, int page_num)
+nautilus_sidebar_tabs_add_view (NautilusSidebarTabs *sidebar_tabs,
+				const char *name,
+				GtkWidget *new_view,
+				int page_num)
 {
 	TabItem *new_tab_item;
 
 	g_return_val_if_fail (NAUTILUS_IS_SIDEBAR_TABS (sidebar_tabs), FALSE);
 	g_return_val_if_fail (name != NULL, FALSE);
-	g_return_val_if_fail (new_view != NULL, FALSE);
+	g_return_val_if_fail (NAUTILUS_IS_VIEW_FRAME (new_view), FALSE);
 
 	/* Check to see if we already have one with this name, if so, refuse to add it */   
 	if (tab_item_find_by_name (sidebar_tabs, name)) {
@@ -1462,10 +1514,12 @@ nautilus_sidebar_tabs_add_view (NautilusSidebarTabs *sidebar_tabs, const char *n
 	
 	/* allocate a new entry, and initialize it */
 	new_tab_item = g_new0 (TabItem, 1);
+	new_tab_item->parent = sidebar_tabs;
 	new_tab_item->tab_text = g_strdup (name);
 	new_tab_item->visible = TRUE;
 	new_tab_item->tab_view = new_view;
 	new_tab_item->notebook_page = page_num;
+	eel_add_weak_pointer (&new_tab_item->tab_view);
 
 	/* add it to the list */
 	sidebar_tabs->details->tab_items = g_list_append (sidebar_tabs->details->tab_items, new_tab_item);
@@ -1478,8 +1532,7 @@ nautilus_sidebar_tabs_add_view (NautilusSidebarTabs *sidebar_tabs, const char *n
 }
 
 /* return the name of the tab with the passed in index */
-
-char*
+char *
 nautilus_sidebar_tabs_get_title_from_index (NautilusSidebarTabs *sidebar_tabs, int which_tab)
 {
 	GList *next_tab;
@@ -1492,12 +1545,11 @@ nautilus_sidebar_tabs_get_title_from_index (NautilusSidebarTabs *sidebar_tabs, i
 			return g_strdup (item->tab_text);
 	}
 	
-	/* shouldn't ever get here... */
+	/* shouldn't ever get here */
 	return g_strdup ("");
 }
 
 /* remove the specified tab entry */
-
 void
 nautilus_sidebar_tabs_remove_view (NautilusSidebarTabs *sidebar_tabs, const char *name)
 {
@@ -1510,7 +1562,6 @@ nautilus_sidebar_tabs_remove_view (NautilusSidebarTabs *sidebar_tabs, const char
 
 	/* Look up the item */
 	tab_item = tab_item_find_by_name (sidebar_tabs, name);
-
 	if (tab_item == NULL) {
 		g_warning ("nautilus_sidebar_tabs_remove_view: Trying to remove a non-existing item '%s'", name);
 		return;
@@ -1537,7 +1588,6 @@ nautilus_sidebar_tabs_remove_view (NautilusSidebarTabs *sidebar_tabs, const char
 
 /* prelight a tab, from its associated notebook page number, by setting the prelight flag of
    the proper tab and clearing the others */
-
 void
 nautilus_sidebar_tabs_prelight_tab (NautilusSidebarTabs *sidebar_tabs, int which_tab)
 {
@@ -1570,7 +1620,6 @@ nautilus_sidebar_tabs_prelight_tab (NautilusSidebarTabs *sidebar_tabs, int which
 
 /* select a tab, from its associated notebook page number, by making it invisible 
    and all the others visible */
-
 void
 nautilus_sidebar_tabs_select_tab (NautilusSidebarTabs *sidebar_tabs, int which_tab)
 {
@@ -1590,7 +1639,7 @@ nautilus_sidebar_tabs_select_tab (NautilusSidebarTabs *sidebar_tabs, int which_t
 
 /* utility routine that returns true if the passed-in color is lighter than average */   
 static gboolean
-is_light_color(GdkColor *color)
+is_light_color (GdkColor *color)
 {
 	int intensity = (((color->red >> 8) * 77) + ((color->green >> 8) * 150) + ((color->blue >> 8) * 28)) >> 8;	
 	return intensity > 160; /* biased slightly toward dark so default of 0x999999 uses light text light Susan specified */
@@ -1661,6 +1710,7 @@ void
 nautilus_sidebar_tabs_set_title_mode (NautilusSidebarTabs *sidebar_tabs, gboolean is_title_mode)
 {
 	g_return_if_fail (NAUTILUS_IS_SIDEBAR_TABS (sidebar_tabs));
+	g_return_if_fail (is_title_mode == FALSE || is_title_mode == TRUE);
 
 	if (sidebar_tabs->details->title_mode != !!is_title_mode) {
 		sidebar_tabs->details->title_mode = !!is_title_mode;
@@ -1670,7 +1720,6 @@ nautilus_sidebar_tabs_set_title_mode (NautilusSidebarTabs *sidebar_tabs, gboolea
 }
 
 /* set the visibility of the selected tab */
-
 void
 nautilus_sidebar_tabs_set_visible (NautilusSidebarTabs *sidebar_tabs,
 				   const char *name,
@@ -1680,10 +1729,10 @@ nautilus_sidebar_tabs_set_visible (NautilusSidebarTabs *sidebar_tabs,
 
 	g_return_if_fail (NAUTILUS_IS_SIDEBAR_TABS (sidebar_tabs));
 	g_return_if_fail (name != NULL);
+	g_return_if_fail (is_visible == FALSE || is_visible == TRUE);
 
 	/* Look up the item */
 	tab_item = tab_item_find_by_name (sidebar_tabs, name);
-
 	if (tab_item == NULL) {
 		g_warning ("nautilus_sidebar_tabs_set_visible: Trying to munge a non-existing item '%s'", name);
 		return;
